@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     01/10/2000
-## RCS-ID:      $Id: Wx.pm,v 1.77 2005/07/05 19:56:12 mbarbon Exp $
+## RCS-ID:      $Id: Wx.pm,v 1.78 2005/07/10 19:03:37 mbarbon Exp $
 ## Copyright:   (c) 2000-2005 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -21,7 +21,7 @@ use vars qw(@ISA $VERSION $AUTOLOAD @EXPORT_OK %EXPORT_TAGS
 $_msw = 1; $_gtk = 2; $_motif = 3; $_mac = 4; $_x11 = 5;
 
 @ISA = qw(Exporter);
-$VERSION = '0.24';
+$VERSION = '0.25';
 
 sub BEGIN{
   @EXPORT_OK = qw(wxPOINT wxSIZE wxTheApp);
@@ -300,6 +300,12 @@ sub LogDebug {
   my( $t ) = sprintf( shift, @_ ); $t =~ s/\%/\%\%/g; wxLogDebug( $t ); 
 }
 
+my $ts_buf;
+
+sub Wx::Log::SetTimestamp {
+    Wx::Log::_SetTimestamp( $_[0], $ts_buf );
+}
+
 1;
 
 __END__
