@@ -501,25 +501,25 @@ sub new {
 [
 	{#State 0
 		ACTIONS => {
-			'p_module' => 12,
-			'p_name' => 2,
-			"class" => 15,
-			'RAW_CODE' => 9,
+			"class" => 5,
+			'p_file' => 13,
+			'p_module' => 11,
+			'RAW_CODE' => 7,
 			'p_typemap' => 1,
-			'p_file' => 17,
-			'OPSPECIAL' => 4
+			'p_name' => 14,
+			'OPSPECIAL' => 2
 		},
 		GOTOS => {
-			'perc_file' => 7,
-			'directive' => 6,
-			'top' => 8,
-			'special_block' => 10,
-			'typemap' => 11,
-			'raw' => 13,
-			'perc_name' => 14,
-			'class' => 3,
-			'perc_module' => 16,
-			'special_block_start' => 5
+			'perc_name' => 4,
+			'top' => 12,
+			'perc_file' => 10,
+			'typemap' => 6,
+			'class' => 16,
+			'directive' => 15,
+			'special_block' => 8,
+			'perc_module' => 9,
+			'raw' => 17,
+			'special_block_start' => 3
 		}
 	},
 	{#State 1
@@ -528,651 +528,697 @@ sub new {
 		}
 	},
 	{#State 2
-		ACTIONS => {
-			'OPCURLY' => 19
-		}
+		DEFAULT => -72
 	},
 	{#State 3
-		DEFAULT => -2
+		ACTIONS => {
+			'line' => 20
+		},
+		GOTOS => {
+			'lines' => 19
+		}
 	},
 	{#State 4
-		DEFAULT => -59
+		ACTIONS => {
+			"class" => 21
+		}
 	},
 	{#State 5
 		ACTIONS => {
-			'line' => 21
-		},
-		GOTOS => {
-			'lines' => 20
+			'ID' => 22
 		}
 	},
 	{#State 6
-		DEFAULT => -3
+		ACTIONS => {
+			'SEMICOLON' => 23
+		}
 	},
 	{#State 7
-		ACTIONS => {
-			'SEMICOLON' => 22
-		}
-	},
-	{#State 8
-		ACTIONS => {
-			'' => 23,
-			'RAW_CODE' => 9,
-			'p_typemap' => 1,
-			'p_name' => 2,
-			'p_module' => 12,
-			"class" => 15,
-			'p_file' => 17,
-			'OPSPECIAL' => 4
-		},
-		GOTOS => {
-			'directive' => 25,
-			'perc_file' => 7,
-			'special_block' => 10,
-			'typemap' => 11,
-			'raw' => 26,
-			'perc_name' => 14,
-			'class' => 24,
-			'perc_module' => 16,
-			'special_block_start' => 5
-		}
-	},
-	{#State 9
 		DEFAULT => -12
 	},
-	{#State 10
+	{#State 8
 		DEFAULT => -13
 	},
+	{#State 9
+		ACTIONS => {
+			'SEMICOLON' => 24
+		}
+	},
+	{#State 10
+		ACTIONS => {
+			'SEMICOLON' => 25
+		}
+	},
 	{#State 11
 		ACTIONS => {
-			'SEMICOLON' => 27
+			'OPCURLY' => 26
 		}
 	},
 	{#State 12
 		ACTIONS => {
-			'OPCURLY' => 28
+			'' => 27,
+			'p_module' => 11,
+			'p_typemap' => 1,
+			'OPSPECIAL' => 2,
+			"class" => 5,
+			'RAW_CODE' => 7,
+			'p_file' => 13,
+			'p_name' => 14
+		},
+		GOTOS => {
+			'perc_name' => 4,
+			'perc_file' => 10,
+			'typemap' => 6,
+			'class' => 29,
+			'directive' => 28,
+			'special_block' => 8,
+			'perc_module' => 9,
+			'raw' => 30,
+			'special_block_start' => 3
 		}
 	},
 	{#State 13
-		DEFAULT => -1
+		ACTIONS => {
+			'OPCURLY' => 31
+		}
 	},
 	{#State 14
-		ACTIONS => {
-			"class" => 29
-		}
-	},
-	{#State 15
-		ACTIONS => {
-			'ID' => 30
-		}
-	},
-	{#State 16
-		ACTIONS => {
-			'SEMICOLON' => 31
-		}
-	},
-	{#State 17
 		ACTIONS => {
 			'OPCURLY' => 32
 		}
 	},
+	{#State 15
+		DEFAULT => -3
+	},
+	{#State 16
+		DEFAULT => -2
+	},
+	{#State 17
+		DEFAULT => -1
+	},
 	{#State 18
 		ACTIONS => {
-			"const" => 33,
-			'ID' => 35
+			'ID' => 33,
+			"short" => 39,
+			"unsigned" => 40,
+			"const" => 35,
+			"long" => 41,
+			"int" => 36,
+			"char" => 43
 		},
 		GOTOS => {
-			'class_name' => 36,
-			'type' => 34
+			'type_name' => 37,
+			'class_name' => 34,
+			'basic_type' => 38,
+			'type' => 42
 		}
 	},
 	{#State 19
 		ACTIONS => {
-			'ID' => 35
+			'CLSPECIAL' => 44,
+			'line' => 45
 		},
 		GOTOS => {
-			'class_name' => 37
+			'special_block_end' => 46
 		}
 	},
 	{#State 20
-		ACTIONS => {
-			'line' => 39,
-			'CLSPECIAL' => 38
-		},
-		GOTOS => {
-			'special_block_end' => 40
-		}
+		DEFAULT => -74
 	},
 	{#State 21
-		DEFAULT => -61
+		ACTIONS => {
+			'ID' => 47
+		}
 	},
 	{#State 22
-		DEFAULT => -8
+		ACTIONS => {
+			'OPCURLY' => 48
+		}
 	},
 	{#State 23
-		DEFAULT => 0
-	},
-	{#State 24
-		DEFAULT => -5
-	},
-	{#State 25
-		DEFAULT => -6
-	},
-	{#State 26
-		DEFAULT => -4
-	},
-	{#State 27
 		DEFAULT => -9
 	},
-	{#State 28
+	{#State 24
+		DEFAULT => -7
+	},
+	{#State 25
+		DEFAULT => -8
+	},
+	{#State 26
 		ACTIONS => {
-			'ID' => 35
+			'ID' => 33
 		},
 		GOTOS => {
-			'class_name' => 41
+			'class_name' => 49
 		}
 	},
+	{#State 27
+		DEFAULT => 0
+	},
+	{#State 28
+		DEFAULT => -6
+	},
 	{#State 29
-		ACTIONS => {
-			'ID' => 42
-		}
+		DEFAULT => -5
 	},
 	{#State 30
-		ACTIONS => {
-			'OPCURLY' => 43
-		}
+		DEFAULT => -4
 	},
 	{#State 31
-		DEFAULT => -7
+		ACTIONS => {
+			'ID' => 50,
+			'DASH' => 52
+		},
+		GOTOS => {
+			'file_name' => 51
+		}
 	},
 	{#State 32
 		ACTIONS => {
-			'ID' => 46,
-			'DASH' => 45
+			'ID' => 33
 		},
 		GOTOS => {
-			'file_name' => 44
+			'class_name' => 53
 		}
 	},
 	{#State 33
 		ACTIONS => {
-			'ID' => 35
+			'DCOLON' => 54
 		},
-		GOTOS => {
-			'class_name' => 47
-		}
+		DEFAULT => -55
 	},
 	{#State 34
-		ACTIONS => {
-			'CLCURLY' => 48
-		}
+		DEFAULT => -45
 	},
 	{#State 35
 		ACTIONS => {
-			'DCOLON' => 49
+			'ID' => 33,
+			"short" => 39,
+			"unsigned" => 40,
+			"long" => 41,
+			"int" => 36,
+			"char" => 43
 		},
-		DEFAULT => -43
+		GOTOS => {
+			'type_name' => 55,
+			'class_name' => 34,
+			'basic_type' => 38
+		}
 	},
 	{#State 36
-		ACTIONS => {
-			'AMP' => 51,
-			'STAR' => 50
-		},
-		DEFAULT => -42
+		DEFAULT => -50
 	},
 	{#State 37
 		ACTIONS => {
-			'CLCURLY' => 52
-		}
+			'STAR' => 57,
+			'AMP' => 56
+		},
+		DEFAULT => -44
 	},
 	{#State 38
-		DEFAULT => -60
+		DEFAULT => -46
 	},
 	{#State 39
-		DEFAULT => -62
+		ACTIONS => {
+			"int" => 58
+		},
+		DEFAULT => -49
 	},
 	{#State 40
-		DEFAULT => -58
+		ACTIONS => {
+			"short" => 39,
+			"unsigned" => 60,
+			"long" => 41,
+			"int" => 36,
+			"char" => 43
+		},
+		DEFAULT => -52,
+		GOTOS => {
+			'basic_type' => 59
+		}
 	},
 	{#State 41
 		ACTIONS => {
-			'CLCURLY' => 53
-		}
+			"int" => 61
+		},
+		DEFAULT => -51
 	},
 	{#State 42
 		ACTIONS => {
-			'OPCURLY' => 54
+			'CLCURLY' => 62
 		}
 	},
 	{#State 43
-		ACTIONS => {
-			'p_name' => 2,
-			"const" => 33,
-			'ID' => 62,
-			'TILDE' => 55,
-			'RAW_CODE' => 60
-		},
-		GOTOS => {
-			'function' => 61,
-			'dtor' => 58,
-			'perc_name' => 63,
-			'methods' => 64,
-			'method' => 57,
-			'ctor' => 56,
-			'class_name' => 36,
-			'type' => 59
-		}
+		DEFAULT => -48
 	},
 	{#State 44
-		ACTIONS => {
-			'CLCURLY' => 65
-		}
+		DEFAULT => -73
 	},
 	{#State 45
-		DEFAULT => -45
+		DEFAULT => -75
 	},
 	{#State 46
-		ACTIONS => {
-			'SLASH' => 67,
-			'DOT' => 66
-		}
+		DEFAULT => -71
 	},
 	{#State 47
 		ACTIONS => {
-			'AMP' => 69,
-			'STAR' => 68
+			'OPCURLY' => 63
 		}
 	},
 	{#State 48
 		ACTIONS => {
-			'OPCURLY' => 70
+			'ID' => 64,
+			'CLCURLY' => 71,
+			"short" => 39,
+			'RAW_CODE' => 67,
+			"const" => 35,
+			"unsigned" => 40,
+			'p_name' => 14,
+			'TILDE' => 72,
+			"long" => 41,
+			"int" => 36,
+			"char" => 43
+		},
+		GOTOS => {
+			'type_name' => 37,
+			'perc_name' => 66,
+			'class_name' => 34,
+			'ctor' => 70,
+			'basic_type' => 38,
+			'function' => 65,
+			'methods' => 68,
+			'dtor' => 74,
+			'type' => 73,
+			'method' => 69
 		}
 	},
 	{#State 49
 		ACTIONS => {
-			'ID' => 71
+			'CLCURLY' => 75
 		}
 	},
 	{#State 50
-		DEFAULT => -40
+		ACTIONS => {
+			'DOT' => 77,
+			'SLASH' => 76
+		}
 	},
 	{#State 51
-		DEFAULT => -41
+		ACTIONS => {
+			'CLCURLY' => 78
+		}
 	},
 	{#State 52
-		DEFAULT => -34
+		DEFAULT => -57
 	},
 	{#State 53
-		DEFAULT => -35
+		ACTIONS => {
+			'CLCURLY' => 79
+		}
 	},
 	{#State 54
 		ACTIONS => {
-			'p_name' => 2,
-			"const" => 33,
-			'ID' => 62,
-			'TILDE' => 55,
-			'RAW_CODE' => 60
-		},
-		GOTOS => {
-			'function' => 61,
-			'dtor' => 58,
-			'perc_name' => 63,
-			'methods' => 72,
-			'method' => 57,
-			'ctor' => 56,
-			'class_name' => 36,
-			'type' => 59
+			'ID' => 80
 		}
 	},
 	{#State 55
 		ACTIONS => {
-			'ID' => 73
+			'STAR' => 82,
+			'AMP' => 81
 		}
 	},
 	{#State 56
-		DEFAULT => -22
+		DEFAULT => -43
 	},
 	{#State 57
-		DEFAULT => -16
+		DEFAULT => -42
 	},
 	{#State 58
-		DEFAULT => -24
+		DEFAULT => -54
 	},
 	{#State 59
-		ACTIONS => {
-			'ID' => 74
-		}
+		DEFAULT => -47
 	},
 	{#State 60
-		DEFAULT => -18
+		DEFAULT => -52
 	},
 	{#State 61
-		DEFAULT => -20
+		DEFAULT => -53
 	},
 	{#State 62
 		ACTIONS => {
-			'DCOLON' => 49,
-			'OPPAR' => 75
-		},
-		DEFAULT => -43
+			'OPCURLY' => 83
+		}
 	},
 	{#State 63
 		ACTIONS => {
-			"const" => 33,
-			'ID' => 62
+			'ID' => 64,
+			'CLCURLY' => 85,
+			"short" => 39,
+			'RAW_CODE' => 67,
+			"const" => 35,
+			"unsigned" => 40,
+			'p_name' => 14,
+			'TILDE' => 72,
+			"long" => 41,
+			"int" => 36,
+			"char" => 43
 		},
 		GOTOS => {
-			'function' => 77,
-			'ctor' => 76,
-			'class_name' => 36,
-			'type' => 59
+			'type_name' => 37,
+			'perc_name' => 66,
+			'class_name' => 34,
+			'ctor' => 70,
+			'basic_type' => 38,
+			'function' => 65,
+			'methods' => 84,
+			'dtor' => 74,
+			'type' => 73,
+			'method' => 69
 		}
 	},
 	{#State 64
 		ACTIONS => {
-			'p_name' => 2,
-			"const" => 33,
-			'ID' => 62,
-			'TILDE' => 55,
-			'RAW_CODE' => 79,
-			'CLCURLY' => 80
+			'DCOLON' => 54,
+			'OPPAR' => 86
 		},
-		GOTOS => {
-			'function' => 61,
-			'dtor' => 58,
-			'perc_name' => 63,
-			'method' => 78,
-			'ctor' => 56,
-			'class_name' => 36,
-			'type' => 59
-		}
+		DEFAULT => -55
 	},
 	{#State 65
-		DEFAULT => -36
+		DEFAULT => -22
 	},
 	{#State 66
 		ACTIONS => {
-			'ID' => 81
+			'ID' => 64,
+			"short" => 39,
+			"unsigned" => 40,
+			"const" => 35,
+			"long" => 41,
+			"int" => 36,
+			"char" => 43
+		},
+		GOTOS => {
+			'type_name' => 37,
+			'class_name' => 34,
+			'ctor' => 88,
+			'basic_type' => 38,
+			'function' => 87,
+			'type' => 73
 		}
 	},
 	{#State 67
-		ACTIONS => {
-			'ID' => 46,
-			'DASH' => 45
-		},
-		GOTOS => {
-			'file_name' => 82
-		}
+		DEFAULT => -20
 	},
 	{#State 68
-		DEFAULT => -38
-	},
-	{#State 69
-		DEFAULT => -39
-	},
-	{#State 70
 		ACTIONS => {
-			'ID' => 83
+			'ID' => 64,
+			'CLCURLY' => 91,
+			"short" => 39,
+			'RAW_CODE' => 89,
+			"const" => 35,
+			"unsigned" => 40,
+			'p_name' => 14,
+			'TILDE' => 72,
+			"long" => 41,
+			"int" => 36,
+			"char" => 43
+		},
+		GOTOS => {
+			'type_name' => 37,
+			'perc_name' => 66,
+			'class_name' => 34,
+			'ctor' => 70,
+			'basic_type' => 38,
+			'function' => 65,
+			'dtor' => 74,
+			'type' => 73,
+			'method' => 90
 		}
 	},
+	{#State 69
+		DEFAULT => -18
+	},
+	{#State 70
+		DEFAULT => -24
+	},
 	{#State 71
-		DEFAULT => -44
+		ACTIONS => {
+			'SEMICOLON' => 92
+		}
 	},
 	{#State 72
 		ACTIONS => {
-			'p_name' => 2,
-			"const" => 33,
-			'ID' => 62,
-			'TILDE' => 55,
-			'RAW_CODE' => 79,
-			'CLCURLY' => 84
-		},
-		GOTOS => {
-			'function' => 61,
-			'dtor' => 58,
-			'perc_name' => 63,
-			'method' => 78,
-			'ctor' => 56,
-			'class_name' => 36,
-			'type' => 59
+			'ID' => 93
 		}
 	},
 	{#State 73
 		ACTIONS => {
-			'OPPAR' => 85
+			'ID' => 94
 		}
 	},
 	{#State 74
-		ACTIONS => {
-			'OPPAR' => 86
-		}
+		DEFAULT => -26
 	},
 	{#State 75
-		ACTIONS => {
-			"const" => 33,
-			'ID' => 35,
-			'CLPAR' => 90
-		},
-		GOTOS => {
-			'arg_list' => 88,
-			'class_name' => 36,
-			'type' => 89,
-			'argument' => 87
-		}
+		DEFAULT => -37
 	},
 	{#State 76
-		DEFAULT => -23
-	},
-	{#State 77
-		DEFAULT => -21
-	},
-	{#State 78
-		DEFAULT => -17
-	},
-	{#State 79
-		DEFAULT => -19
-	},
-	{#State 80
 		ACTIONS => {
-			'SEMICOLON' => 91
+			'ID' => 50,
+			'DASH' => 52
+		},
+		GOTOS => {
+			'file_name' => 95
 		}
 	},
+	{#State 77
+		ACTIONS => {
+			'ID' => 96
+		}
+	},
+	{#State 78
+		DEFAULT => -38
+	},
+	{#State 79
+		DEFAULT => -36
+	},
+	{#State 80
+		DEFAULT => -56
+	},
 	{#State 81
-		DEFAULT => -46
+		DEFAULT => -41
 	},
 	{#State 82
-		DEFAULT => -47
+		DEFAULT => -40
 	},
 	{#State 83
 		ACTIONS => {
-			'CLCURLY' => 92
+			'ID' => 97
 		}
 	},
 	{#State 84
 		ACTIONS => {
-			'SEMICOLON' => 93
+			'ID' => 64,
+			'CLCURLY' => 98,
+			"short" => 39,
+			'RAW_CODE' => 89,
+			"const" => 35,
+			"unsigned" => 40,
+			'p_name' => 14,
+			'TILDE' => 72,
+			"long" => 41,
+			"int" => 36,
+			"char" => 43
+		},
+		GOTOS => {
+			'type_name' => 37,
+			'perc_name' => 66,
+			'class_name' => 34,
+			'ctor' => 70,
+			'basic_type' => 38,
+			'function' => 65,
+			'dtor' => 74,
+			'type' => 73,
+			'method' => 90
 		}
 	},
 	{#State 85
 		ACTIONS => {
-			'CLPAR' => 94
+			'SEMICOLON' => 99
 		}
 	},
 	{#State 86
 		ACTIONS => {
-			"const" => 33,
-			'ID' => 35,
-			'CLPAR' => 96
+			'ID' => 33,
+			"short" => 39,
+			'CLPAR' => 102,
+			"const" => 35,
+			"unsigned" => 40,
+			"long" => 41,
+			"int" => 36,
+			"char" => 43
 		},
 		GOTOS => {
-			'arg_list' => 95,
-			'class_name' => 36,
-			'type' => 89,
-			'argument' => 87
+			'type_name' => 37,
+			'argument' => 101,
+			'class_name' => 34,
+			'basic_type' => 38,
+			'type' => 103,
+			'arg_list' => 100
 		}
 	},
 	{#State 87
-		DEFAULT => -48
+		DEFAULT => -23
 	},
 	{#State 88
-		ACTIONS => {
-			'COMMA' => 98,
-			'CLPAR' => 97
-		}
+		DEFAULT => -25
 	},
 	{#State 89
-		ACTIONS => {
-			'ID' => 99
-		}
+		DEFAULT => -21
 	},
 	{#State 90
-		ACTIONS => {
-			'p_code' => 101
-		},
-		DEFAULT => -33,
-		GOTOS => {
-			'metadata' => 102,
-			'perc_code' => 100
-		}
+		DEFAULT => -19
 	},
 	{#State 91
-		DEFAULT => -15
-	},
-	{#State 92
-		ACTIONS => {
-			'OPSPECIAL' => 4
-		},
-		DEFAULT => -10,
-		GOTOS => {
-			'special_block' => 103,
-			'special_block_start' => 5
-		}
-	},
-	{#State 93
-		DEFAULT => -14
-	},
-	{#State 94
 		ACTIONS => {
 			'SEMICOLON' => 104
 		}
 	},
-	{#State 95
+	{#State 92
+		DEFAULT => -17
+	},
+	{#State 93
 		ACTIONS => {
-			'COMMA' => 98,
-			'CLPAR' => 105
+			'OPPAR' => 105
 		}
 	},
-	{#State 96
+	{#State 94
 		ACTIONS => {
-			'p_code' => 101
-		},
-		DEFAULT => -33,
-		GOTOS => {
-			'metadata' => 106,
-			'perc_code' => 100
+			'OPPAR' => 106
 		}
 	},
+	{#State 95
+		DEFAULT => -59
+	},
+	{#State 96
+		DEFAULT => -58
+	},
 	{#State 97
 		ACTIONS => {
-			'p_code' => 101
-		},
-		DEFAULT => -33,
-		GOTOS => {
-			'metadata' => 107,
-			'perc_code' => 100
+			'CLCURLY' => 107
 		}
 	},
 	{#State 98
 		ACTIONS => {
-			"const" => 33,
-			'ID' => 35
-		},
-		GOTOS => {
-			'class_name' => 36,
-			'type' => 89,
-			'argument' => 108
+			'SEMICOLON' => 108
 		}
 	},
 	{#State 99
-		ACTIONS => {
-			'EQUAL' => 109
-		},
-		DEFAULT => -50
+		DEFAULT => -16
 	},
 	{#State 100
-		DEFAULT => -32
+		ACTIONS => {
+			'CLPAR' => 110,
+			'COMMA' => 109
+		}
 	},
 	{#State 101
-		ACTIONS => {
-			'OPSPECIAL' => 4
-		},
-		GOTOS => {
-			'special_block' => 110,
-			'special_block_start' => 5
-		}
+		DEFAULT => -60
 	},
 	{#State 102
 		ACTIONS => {
-			'SEMICOLON' => 111
+			'p_code' => 112
+		},
+		DEFAULT => -35,
+		GOTOS => {
+			'perc_code' => 111,
+			'metadata' => 113
 		}
 	},
 	{#State 103
-		DEFAULT => -11
+		ACTIONS => {
+			'ID' => 114
+		}
 	},
 	{#State 104
-		DEFAULT => -31
+		DEFAULT => -15
 	},
 	{#State 105
 		ACTIONS => {
-			'p_code' => 101
-		},
-		DEFAULT => -33,
-		GOTOS => {
-			'metadata' => 112,
-			'perc_code' => 100
+			'CLPAR' => 115
 		}
 	},
 	{#State 106
 		ACTIONS => {
-			"const" => 114
+			'ID' => 33,
+			"short" => 39,
+			'CLPAR' => 117,
+			"const" => 35,
+			"unsigned" => 40,
+			"long" => 41,
+			"int" => 36,
+			"char" => 43
 		},
-		DEFAULT => -26,
 		GOTOS => {
-			'const' => 113
+			'type_name' => 37,
+			'argument' => 101,
+			'class_name' => 34,
+			'basic_type' => 38,
+			'type' => 103,
+			'arg_list' => 116
 		}
 	},
 	{#State 107
 		ACTIONS => {
-			'SEMICOLON' => 115
+			'OPSPECIAL' => 2
+		},
+		DEFAULT => -10,
+		GOTOS => {
+			'special_block' => 118,
+			'special_block_start' => 3
 		}
 	},
 	{#State 108
-		DEFAULT => -49
+		DEFAULT => -14
 	},
 	{#State 109
 		ACTIONS => {
-			'QUOTED_STRING' => 116,
-			'ID' => 120,
-			'DASH' => 117,
-			'INTEGER' => 118
+			'ID' => 33,
+			"short" => 39,
+			"unsigned" => 40,
+			"const" => 35,
+			"long" => 41,
+			"int" => 36,
+			"char" => 43
 		},
 		GOTOS => {
-			'value' => 119
+			'type_name' => 37,
+			'argument' => 119,
+			'class_name' => 34,
+			'basic_type' => 38,
+			'type' => 103
 		}
 	},
 	{#State 110
-		DEFAULT => -37
+		ACTIONS => {
+			'p_code' => 112
+		},
+		DEFAULT => -35,
+		GOTOS => {
+			'perc_code' => 111,
+			'metadata' => 120
+		}
 	},
 	{#State 111
-		DEFAULT => -30
+		DEFAULT => -34
 	},
 	{#State 112
 		ACTIONS => {
-			"const" => 114
+			'OPSPECIAL' => 2
 		},
-		DEFAULT => -26,
 		GOTOS => {
-			'const' => 121
+			'special_block' => 121,
+			'special_block_start' => 3
 		}
 	},
 	{#State 113
@@ -1181,72 +1227,168 @@ sub new {
 		}
 	},
 	{#State 114
-		DEFAULT => -25
+		ACTIONS => {
+			'EQUAL' => 123
+		},
+		DEFAULT => -62
 	},
 	{#State 115
-		DEFAULT => -29
+		ACTIONS => {
+			'SEMICOLON' => 124
+		}
 	},
 	{#State 116
-		DEFAULT => -54
+		ACTIONS => {
+			'CLPAR' => 125,
+			'COMMA' => 109
+		}
 	},
 	{#State 117
 		ACTIONS => {
-			'INTEGER' => 123
+			'p_code' => 112
+		},
+		DEFAULT => -35,
+		GOTOS => {
+			'perc_code' => 111,
+			'metadata' => 126
 		}
 	},
 	{#State 118
-		DEFAULT => -52
+		DEFAULT => -11
 	},
 	{#State 119
-		DEFAULT => -51
+		DEFAULT => -61
 	},
 	{#State 120
 		ACTIONS => {
-			'DCOLON' => 124,
-			'OPPAR' => 125
-		},
-		DEFAULT => -55
+			'SEMICOLON' => 127
+		}
 	},
 	{#State 121
-		ACTIONS => {
-			'SEMICOLON' => 126
-		}
+		DEFAULT => -39
 	},
 	{#State 122
-		DEFAULT => -28
+		DEFAULT => -32
 	},
 	{#State 123
-		DEFAULT => -53
+		ACTIONS => {
+			'INTEGER' => 131,
+			'ID' => 128,
+			'QUOTED_STRING' => 133,
+			'DASH' => 130,
+			'FLOAT' => 129
+		},
+		GOTOS => {
+			'value' => 132
+		}
 	},
 	{#State 124
-		ACTIONS => {
-			'ID' => 127
-		}
+		DEFAULT => -33
 	},
 	{#State 125
 		ACTIONS => {
-			'QUOTED_STRING' => 116,
-			'ID' => 120,
-			'DASH' => 117,
-			'INTEGER' => 118
+			'p_code' => 112
 		},
+		DEFAULT => -35,
 		GOTOS => {
-			'value' => 128
+			'perc_code' => 111,
+			'metadata' => 134
 		}
 	},
 	{#State 126
-		DEFAULT => -27
+		ACTIONS => {
+			"const" => 135
+		},
+		DEFAULT => -28,
+		GOTOS => {
+			'const' => 136
+		}
 	},
 	{#State 127
-		DEFAULT => -56
+		DEFAULT => -31
 	},
 	{#State 128
 		ACTIONS => {
-			'CLPAR' => 129
-		}
+			'DCOLON' => 137,
+			'OPPAR' => 138
+		},
+		DEFAULT => -68
 	},
 	{#State 129
-		DEFAULT => -57
+		DEFAULT => -66
+	},
+	{#State 130
+		ACTIONS => {
+			'INTEGER' => 139
+		}
+	},
+	{#State 131
+		DEFAULT => -64
+	},
+	{#State 132
+		DEFAULT => -63
+	},
+	{#State 133
+		DEFAULT => -67
+	},
+	{#State 134
+		ACTIONS => {
+			"const" => 135
+		},
+		DEFAULT => -28,
+		GOTOS => {
+			'const' => 140
+		}
+	},
+	{#State 135
+		DEFAULT => -27
+	},
+	{#State 136
+		ACTIONS => {
+			'SEMICOLON' => 141
+		}
+	},
+	{#State 137
+		ACTIONS => {
+			'ID' => 142
+		}
+	},
+	{#State 138
+		ACTIONS => {
+			'INTEGER' => 131,
+			'ID' => 128,
+			'QUOTED_STRING' => 133,
+			'DASH' => 130,
+			'FLOAT' => 129
+		},
+		GOTOS => {
+			'value' => 143
+		}
+	},
+	{#State 139
+		DEFAULT => -65
+	},
+	{#State 140
+		ACTIONS => {
+			'SEMICOLON' => 144
+		}
+	},
+	{#State 141
+		DEFAULT => -30
+	},
+	{#State 142
+		DEFAULT => -69
+	},
+	{#State 143
+		ACTIONS => {
+			'CLPAR' => 145
+		}
+	},
+	{#State 144
+		DEFAULT => -29
+	},
+	{#State 145
+		DEFAULT => -70
 	}
 ],
                                   yyrules  =>
@@ -1357,33 +1499,46 @@ sub
                                      methods => $_[4] ) }
 	],
 	[#Rule 16
-		 'methods', 1,
+		 'class', 6,
 sub
 #line 59 "script/XSP.yp"
-{ [ $_[1] ] }
+{ add_data_class( $_[0], class   => $_[3],
+                                     perl    => $_[1] ) }
 	],
 	[#Rule 17
-		 'methods', 2,
+		 'class', 5,
 sub
-#line 60 "script/XSP.yp"
-{ push @{$_[1]}, $_[2]; $_[1] }
+#line 62 "script/XSP.yp"
+{ add_data_class( $_[0], class   => $_[2] ) }
 	],
 	[#Rule 18
 		 'methods', 1,
 sub
-#line 61 "script/XSP.yp"
-{ [ add_data_raw( $_[0], [ $_[1] ] ) ] }
+#line 64 "script/XSP.yp"
+{ [ $_[1] ] }
 	],
 	[#Rule 19
 		 'methods', 2,
 sub
-#line 63 "script/XSP.yp"
-{ push @{$_[1]}, add_data_raw( $_[0], [ $_[2] ] ); $_[1] }
+#line 65 "script/XSP.yp"
+{ push @{$_[1]}, $_[2]; $_[1] }
 	],
 	[#Rule 20
+		 'methods', 1,
+sub
+#line 66 "script/XSP.yp"
+{ [ add_data_raw( $_[0], [ $_[1] ] ) ] }
+	],
+	[#Rule 21
+		 'methods', 2,
+sub
+#line 68 "script/XSP.yp"
+{ push @{$_[1]}, add_data_raw( $_[0], [ $_[2] ] ); $_[1] }
+	],
+	[#Rule 22
 		 'method', 1,
 sub
-#line 65 "script/XSP.yp"
+#line 70 "script/XSP.yp"
 { my $f = $_[1];
                            my $m = add_data_method
                              ( $_[0],
@@ -1394,10 +1549,10 @@ sub
                            $m
                          }
 	],
-	[#Rule 21
+	[#Rule 23
 		 'method', 2,
 sub
-#line 75 "script/XSP.yp"
+#line 80 "script/XSP.yp"
 { my $f = $_[2];
                       my $m = add_data_method
                         ( $_[0],
@@ -1409,236 +1564,269 @@ sub
                       $m
                     }
 	],
-	[#Rule 22
-		 'method', 1, undef
-	],
-	[#Rule 23
-		 'method', 2,
-sub
-#line 87 "script/XSP.yp"
-{ $_[2]->{PERL_NAME} = $_[1]; $_[2] }
-	],
 	[#Rule 24
 		 'method', 1, undef
 	],
 	[#Rule 25
-		 'const', 1, undef
+		 'method', 2,
+sub
+#line 92 "script/XSP.yp"
+{ $_[2]->{PERL_NAME} = $_[1]; $_[2] }
 	],
 	[#Rule 26
-		 'const', 0, undef
+		 'method', 1, undef
 	],
 	[#Rule 27
+		 'const', 1, undef
+	],
+	[#Rule 28
+		 'const', 0, undef
+	],
+	[#Rule 29
 		 'function', 8,
 sub
-#line 94 "script/XSP.yp"
+#line 99 "script/XSP.yp"
 { add_data_function( $_[0],
                                          name      => $_[2],
                                          ret_type  => $_[1],
                                          arguments => $_[4],
                                          @{ $_[6] } ) }
 	],
-	[#Rule 28
+	[#Rule 30
 		 'function', 7,
 sub
-#line 100 "script/XSP.yp"
+#line 105 "script/XSP.yp"
 { add_data_function( $_[0],
                                          name     => $_[2],
                                          ret_type => $_[1],
                                          @{ $_[5] } ) }
 	],
-	[#Rule 29
+	[#Rule 31
 		 'ctor', 6,
 sub
-#line 106 "script/XSP.yp"
+#line 111 "script/XSP.yp"
 { add_data_ctor( $_[0], name      => $_[1],
                                             arguments => $_[3],
                                             @{ $_[5] } ) }
 	],
-	[#Rule 30
+	[#Rule 32
 		 'ctor', 5,
 sub
-#line 110 "script/XSP.yp"
+#line 115 "script/XSP.yp"
 { add_data_ctor( $_[0], name => $_[1],
                                             @{ $_[4] } ) }
 	],
-	[#Rule 31
+	[#Rule 33
 		 'dtor', 5,
 sub
-#line 114 "script/XSP.yp"
+#line 119 "script/XSP.yp"
 { add_data_dtor( $_[0], $_[2] ) }
 	],
-	[#Rule 32
+	[#Rule 34
 		 'metadata', 1,
 sub
-#line 116 "script/XSP.yp"
+#line 121 "script/XSP.yp"
 { $_[1] }
 	],
-	[#Rule 33
+	[#Rule 35
 		 'metadata', 0,
 sub
-#line 117 "script/XSP.yp"
+#line 122 "script/XSP.yp"
 { [] }
 	],
-	[#Rule 34
+	[#Rule 36
 		 'perc_name', 4,
 sub
-#line 119 "script/XSP.yp"
-{ $_[3] }
-	],
-	[#Rule 35
-		 'perc_module', 4,
-sub
-#line 120 "script/XSP.yp"
-{ $_[3] }
-	],
-	[#Rule 36
-		 'perc_file', 4,
-sub
-#line 121 "script/XSP.yp"
+#line 124 "script/XSP.yp"
 { $_[3] }
 	],
 	[#Rule 37
-		 'perc_code', 2,
-sub
-#line 122 "script/XSP.yp"
-{ [ code => $_[2] ] }
-	],
-	[#Rule 38
-		 'type', 3,
-sub
-#line 124 "script/XSP.yp"
-{ make_cptr( $_[0], $_[2] ) }
-	],
-	[#Rule 39
-		 'type', 3,
+		 'perc_module', 4,
 sub
 #line 125 "script/XSP.yp"
-{ make_cref( $_[0], $_[2] ) }
+{ $_[3] }
 	],
-	[#Rule 40
-		 'type', 2,
+	[#Rule 38
+		 'perc_file', 4,
 sub
 #line 126 "script/XSP.yp"
-{ make_ptr( $_[0], $_[1] ) }
+{ $_[3] }
 	],
-	[#Rule 41
-		 'type', 2,
+	[#Rule 39
+		 'perc_code', 2,
 sub
 #line 127 "script/XSP.yp"
-{ make_ref( $_[0], $_[1] ) }
+{ [ code => $_[2] ] }
+	],
+	[#Rule 40
+		 'type', 3,
+sub
+#line 129 "script/XSP.yp"
+{ make_cptr( $_[0], $_[2] ) }
+	],
+	[#Rule 41
+		 'type', 3,
+sub
+#line 130 "script/XSP.yp"
+{ make_cref( $_[0], $_[2] ) }
 	],
 	[#Rule 42
-		 'type', 1,
-sub
-#line 128 "script/XSP.yp"
-{ make_type( $_[0], $_[1] ) }
-	],
-	[#Rule 43
-		 'class_name', 1, undef
-	],
-	[#Rule 44
-		 'class_name', 3,
+		 'type', 2,
 sub
 #line 131 "script/XSP.yp"
-{ $_[1] . '::' . $_[3] }
+{ make_ptr( $_[0], $_[1] ) }
 	],
-	[#Rule 45
-		 'file_name', 1,
+	[#Rule 43
+		 'type', 2,
+sub
+#line 132 "script/XSP.yp"
+{ make_ref( $_[0], $_[1] ) }
+	],
+	[#Rule 44
+		 'type', 1,
 sub
 #line 133 "script/XSP.yp"
-{ '-' }
+{ make_type( $_[0], $_[1] ) }
+	],
+	[#Rule 45
+		 'type_name', 1, undef
 	],
 	[#Rule 46
-		 'file_name', 3,
-sub
-#line 134 "script/XSP.yp"
-{ $_[1] . '.' . $_[3] }
+		 'type_name', 1, undef
 	],
 	[#Rule 47
-		 'file_name', 3,
-sub
-#line 135 "script/XSP.yp"
-{ $_[1] . '/' . $_[3] }
+		 'type_name', 2, undef
 	],
 	[#Rule 48
-		 'arg_list', 1,
-sub
-#line 137 "script/XSP.yp"
-{ [ $_[1] ] }
+		 'basic_type', 1, undef
 	],
 	[#Rule 49
-		 'arg_list', 3,
-sub
-#line 138 "script/XSP.yp"
-{ push @{$_[1]}, $_[3]; $_[1] }
+		 'basic_type', 1, undef
 	],
 	[#Rule 50
-		 'argument', 2,
-sub
-#line 140 "script/XSP.yp"
-{ make_argument( @_ ) }
+		 'basic_type', 1, undef
 	],
 	[#Rule 51
-		 'argument', 4,
-sub
-#line 142 "script/XSP.yp"
-{ make_argument( @_[0, 1, 2, 4] ) }
+		 'basic_type', 1, undef
 	],
 	[#Rule 52
-		 'value', 1, undef
+		 'basic_type', 1, undef
 	],
 	[#Rule 53
-		 'value', 2,
-sub
-#line 145 "script/XSP.yp"
-{ '-' . $_[2] }
+		 'basic_type', 2, undef
 	],
 	[#Rule 54
-		 'value', 1, undef
+		 'basic_type', 2, undef
 	],
 	[#Rule 55
-		 'value', 1, undef
+		 'class_name', 1, undef
 	],
 	[#Rule 56
-		 'value', 3,
+		 'class_name', 3,
 sub
-#line 148 "script/XSP.yp"
+#line 141 "script/XSP.yp"
 { $_[1] . '::' . $_[3] }
 	],
 	[#Rule 57
-		 'value', 4,
+		 'file_name', 1,
 sub
-#line 149 "script/XSP.yp"
-{ "$_[1]($_[3])" }
+#line 143 "script/XSP.yp"
+{ '-' }
 	],
 	[#Rule 58
-		 'special_block', 3,
+		 'file_name', 3,
 sub
-#line 154 "script/XSP.yp"
-{ $_[2] }
+#line 144 "script/XSP.yp"
+{ $_[1] . '.' . $_[3] }
 	],
 	[#Rule 59
-		 'special_block_start', 1,
+		 'file_name', 3,
 sub
-#line 156 "script/XSP.yp"
-{ push_lex_mode( $_[0], 'special' ) }
+#line 145 "script/XSP.yp"
+{ $_[1] . '/' . $_[3] }
 	],
 	[#Rule 60
-		 'special_block_end', 1,
+		 'arg_list', 1,
 sub
-#line 158 "script/XSP.yp"
-{ pop_lex_mode( $_[0], 'special' ) }
-	],
-	[#Rule 61
-		 'lines', 1,
-sub
-#line 160 "script/XSP.yp"
+#line 147 "script/XSP.yp"
 { [ $_[1] ] }
+	],
+	[#Rule 61
+		 'arg_list', 3,
+sub
+#line 148 "script/XSP.yp"
+{ push @{$_[1]}, $_[3]; $_[1] }
 	],
 	[#Rule 62
+		 'argument', 2,
+sub
+#line 150 "script/XSP.yp"
+{ make_argument( @_ ) }
+	],
+	[#Rule 63
+		 'argument', 4,
+sub
+#line 152 "script/XSP.yp"
+{ make_argument( @_[0, 1, 2, 4] ) }
+	],
+	[#Rule 64
+		 'value', 1, undef
+	],
+	[#Rule 65
+		 'value', 2,
+sub
+#line 155 "script/XSP.yp"
+{ '-' . $_[2] }
+	],
+	[#Rule 66
+		 'value', 1, undef
+	],
+	[#Rule 67
+		 'value', 1, undef
+	],
+	[#Rule 68
+		 'value', 1, undef
+	],
+	[#Rule 69
+		 'value', 3,
+sub
+#line 159 "script/XSP.yp"
+{ $_[1] . '::' . $_[3] }
+	],
+	[#Rule 70
+		 'value', 4,
+sub
+#line 160 "script/XSP.yp"
+{ "$_[1]($_[3])" }
+	],
+	[#Rule 71
+		 'special_block', 3,
+sub
+#line 165 "script/XSP.yp"
+{ $_[2] }
+	],
+	[#Rule 72
+		 'special_block_start', 1,
+sub
+#line 167 "script/XSP.yp"
+{ push_lex_mode( $_[0], 'special' ) }
+	],
+	[#Rule 73
+		 'special_block_end', 1,
+sub
+#line 169 "script/XSP.yp"
+{ pop_lex_mode( $_[0], 'special' ) }
+	],
+	[#Rule 74
+		 'lines', 1,
+sub
+#line 171 "script/XSP.yp"
+{ [ $_[1] ] }
+	],
+	[#Rule 75
 		 'lines', 2,
 sub
-#line 161 "script/XSP.yp"
+#line 172 "script/XSP.yp"
 { push @{$_[1]}, $_[2]; $_[1] }
 	]
 ],
@@ -1646,7 +1834,7 @@ sub
     bless($self,$class);
 }
 
-#line 163 "script/XSP.yp"
+#line 174 "script/XSP.yp"
 
 
 my %tokens = ( '::' => 'DCOLON',
@@ -1677,6 +1865,11 @@ my %tokens = ( '::' => 'DCOLON',
 
 my %keywords = ( const => 1,
                  class => 1,
+                 unsigned => 1,
+                 short => 1,
+                 long => 1,
+                 int => 1,
+                 char => 1,
                );
 
 sub get_lex_mode { return $_[0]->YYData->{LEX}{MODES}[0] || '' }
@@ -1734,7 +1927,10 @@ sub yylex {
       $$buf =~ s/^[\s\n\r]+//;
       next unless length $$buf;
 
-      if( $$buf =~ s/^( \%}
+
+      if( $$buf =~ s/^([+-]?(?=\d|\.\d)\d*(?:\.\d*)?(?:[Ee](?:[+-]?\d+))?)// ) {
+        return ( 'FLOAT', $1 );
+      } elsif( $$buf =~ s/^( \%}
                       | \%{ | {\%
                       | \%name | \%typemap | \%module | \%typemap | \%code
                       | \%file
@@ -1762,12 +1958,15 @@ sub yylex {
 }
 
 sub yyerror {
-  my $buf = $_[0]->YYData->{LEX}{BUFFER};
-
-  print "Error: (", $_[0]->YYCurtok, ') (',
+  my $data = $_[0]->YYData->{LEX};
+  my $buf = $data->{BUFFER};
+  my $fh = $data->{FH};
+   
+  print STDERR "Error: line " . $fh->input_line_number . " (",
+    $_[0]->YYCurtok, ') (',
     $_[0]->YYCurval, ') "', ( $buf ? $$buf : '--empty buffer--' ),
       q{"} . "\n";
-  print "Expecting: (", ( join ", ", map { "'$_'" } $_[0]->YYExpect ),
+  print STDERR "Expecting: (", ( join ", ", map { "'$_'" } $_[0]->YYExpect ),
         ")\n";
 }
 
